import { Switch, Route } from "wouter";
import { queryClient } from "./lib/queryClient";
import { QueryClientProvider } from "@tanstack/react-query";
import { Toaster } from "@/components/ui/toaster";
import { TooltipProvider } from "@/components/ui/tooltip";
import { AuthProvider } from "@/contexts/AuthContext";
import { LanguageProvider } from "@/contexts/LanguageContext";
import { useAuth } from "@/contexts/AuthContext";
import { getRedirectResult, GoogleAuthProvider } from "firebase/auth";
import { auth } from "@/lib/firebase";
import { useEffect, lazy, Suspense } from "react";
import { useToast } from "@/hooks/use-toast";
import { LoadingScreen } from "@/components/LoadingScreen";
import SEOHead from "@/components/SEOHead";

// Eager load critical pages
import Welcome from "@/pages/Welcome";
import Login from "@/pages/Login";
import Register from "@/pages/Register";
import Dashboard from "@/pages/Dashboard";

// Lazy load secondary pages for better performance
const SendTopUp = lazy(() => import("@/pages/SendTopUp"));
const Wallet = lazy(() => import("@/pages/Wallet"));
const TransactionHistory = lazy(() => import("@/pages/TransactionHistory"));
const Profile = lazy(() => import("@/pages/Profile"));
const Promotions = lazy(() => import("@/pages/PromotionsNew"));
const InviteFriends = lazy(() => import("@/pages/InviteFriends"));
const Loyalty = lazy(() => import("@/pages/Loyalty"));
const Settings = lazy(() => import("@/pages/Settings"));
const SecuritySettings = lazy(() => import("@/pages/SecuritySettings"));
const Support = lazy(() => import("@/pages/Support"));
const PrivacyPolicy = lazy(() => import("@/pages/PrivacyPolicy"));
const TermsOfService = lazy(() => import("@/pages/TermsOfService"));
const AdminPanel = lazy(() => import("@/pages/AdminPanel"));
const PayPalSetup = lazy(() => import("@/pages/PayPalSetup"));
const ServiceFees = lazy(() => import("@/pages/ServiceFees"));
const PaymentSummaryPage = lazy(() => import("@/pages/PaymentSummaryPage"));
const WalletSummaryPage = lazy(() => import("@/pages/WalletSummaryPage"));
const NotFound = lazy(() => import("@/pages/not-found"));

// Import translation setup
import "@/lib/i18n";

function AuthenticatedRoutes() {
  return (
    <Suspense fallback={<LoadingScreen />}>
      <Switch>
        <Route path="/dashboard" component={Dashboard} />
        <Route path="/send-topup" component={SendTopUp} />
        <Route path="/wallet" component={Wallet} />
        <Route path="/history" component={TransactionHistory} />
        <Route path="/profile" component={Profile} />
        <Route path="/promotions" component={Promotions} />
        <Route path="/invite-friends" component={InviteFriends} />
        <Route path="/loyalty" component={Loyalty} />
        <Route path="/settings" component={Settings} />
        <Route path="/security-settings" component={SecuritySettings} />
        <Route path="/support" component={Support} />
        <Route path="/privacy-policy" component={PrivacyPolicy} />
        <Route path="/terms-of-service" component={TermsOfService} />
        <Route path="/admin" component={AdminPanel} />
        <Route path="/paypal-setup" component={PayPalSetup} />
        <Route path="/service-fees" component={ServiceFees} />
        <Route path="/payment-summary" component={PaymentSummaryPage} />
        <Route path="/wallet-summary" component={WalletSummaryPage} />
        <Route path="/" component={Dashboard} />
        <Route component={NotFound} />
      </Switch>
    </Suspense>
  );
}

function UnauthenticatedRoutes() {
  return (
    <Switch>
      <Route path="/login" component={Login} />
      <Route path="/register" component={Register} />
      <Route path="/" component={Welcome} />
      <Route component={Welcome} />
    </Switch>
  );
}

function Router() {
  const { user, loading } = useAuth();
  const { toast } = useToast();

  // Handle Google redirect result
  useEffect(() => {
    const handleRedirectResult = async () => {
      try {
        const result = await getRedirectResult(auth);
        if (result) {
          // User signed in successfully via redirect
          const credential = GoogleAuthProvider.credentialFromResult(result);
          console.log('Google sign-in successful', result.user);
        }
      } catch (error: any) {
        console.error('Google sign-in error:', error);
        toast({
          title: "Sign-in Error",
          description: error.message,
          variant: "destructive",
        });
      }
    };

    handleRedirectResult();
  }, [toast]);

  if (loading) {
    return <LoadingScreen message="Loading BuyFast TopUp..." size="fullscreen" />;
  }

  return user ? <AuthenticatedRoutes /> : <UnauthenticatedRoutes />;
}

function App() {
  return (
    <QueryClientProvider client={queryClient}>
      <LanguageProvider>
        <AuthProvider>
          <TooltipProvider>
            <SEOHead />
            <Toaster />
            <Router />
          </TooltipProvider>
        </AuthProvider>
      </LanguageProvider>
    </QueryClientProvider>
  );
}

export default App;
